==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/DNSRecordStatusBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DNSRecordStatusBuilder extends io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluentImpl<io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.DNSRecordStatus,io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusBuilder>{
  public DNSRecordStatusBuilder() {
    this(false);
  }
  public DNSRecordStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new DNSRecordStatus(), validationEnabled);
  }
  public DNSRecordStatusBuilder(io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public DNSRecordStatusBuilder(io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DNSRecordStatus(), validationEnabled);
  }
  public DNSRecordStatusBuilder(io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.DNSRecordStatus instance) {
    this(fluent, instance, false);
  }
  public DNSRecordStatusBuilder(io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.DNSRecordStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withZones(instance.getZones()); 
    this.validationEnabled = validationEnabled; 
  }
  public DNSRecordStatusBuilder(io.fabric8.openshift.api.model.operator.v1.DNSRecordStatus instance) {
    this(instance,false);
  }
  public DNSRecordStatusBuilder(io.fabric8.openshift.api.model.operator.v1.DNSRecordStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withZones(instance.getZones()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.DNSRecordStatus build() {
    DNSRecordStatus buildable = new DNSRecordStatus(fluent.getObservedGeneration(),fluent.getZones());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DNSRecordStatusBuilder that = (DNSRecordStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.12.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/DNSRecordStatusBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DNSRecordStatusBuilder extends io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluentImpl<io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.DNSRecordStatus,io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusBuilder>{
  public DNSRecordStatusBuilder() {
    this(false);
  }
  public DNSRecordStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new DNSRecordStatus(), validationEnabled);
  }
  public DNSRecordStatusBuilder(io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public DNSRecordStatusBuilder(io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DNSRecordStatus(), validationEnabled);
  }
  public DNSRecordStatusBuilder(io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.DNSRecordStatus instance) {
    this(fluent, instance, false);
  }
  public DNSRecordStatusBuilder(io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.DNSRecordStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withZones(instance.getZones()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DNSRecordStatusBuilder(io.fabric8.openshift.api.model.operator.v1.DNSRecordStatus instance) {
    this(instance,false);
  }
  public DNSRecordStatusBuilder(io.fabric8.openshift.api.model.operator.v1.DNSRecordStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withZones(instance.getZones()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.DNSRecordStatus build() {
    DNSRecordStatus buildable = new DNSRecordStatus(fluent.getObservedGeneration(),fluent.getZones());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DNSRecordStatusBuilder that = (DNSRecordStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
